@@ -1,4 +1,4 @@
-from distutils.version import LooseVersion
+from packaging.version import Version
 import math
 from typing import Sequence
 from geopandas.testing import assert_geodataframe_equal
@@ -137,7 +137,7 @@ class TestSpatialJoin:
         if op != predicate:
             warntype = UserWarning
             match = (
-                "`predicate` will be overriden by the value of `op`"
+                "`predicate` will be overridden by the value of `op`"
                 + r"(.|\s)*"
                 + match
             )
@@ -354,7 +354,7 @@ class TestSpatialJoin:
             exp.index.names = df2.index.names
 
         # GH 1364 fix of behaviour was done in pandas 1.1.0
-        if predicate == "within" and str(pd.__version__) >= LooseVersion("1.1.0"):
+        if predicate == "within" and Version(pd.__version__) >= Version("1.1.0"):
             exp = exp.sort_index()
 
         assert_frame_equal(res, exp, check_index_type=False)
@@ -767,14 +767,14 @@ class TestNearest:
                 [Point(1, 1), Point(0.25, 1)],
                 [0, 1],
                 [1, 0],
-                [math.sqrt(0.25 ** 2 + 1), 0],
+                [math.sqrt(0.25**2 + 1), 0],
             ),
             (
                 [Point(0, 0), Point(1, 1)],
                 [Point(-10, -10), Point(100, 100)],
                 [0, 1],
                 [0, 0],
-                [math.sqrt(10 ** 2 + 10 ** 2), math.sqrt(11 ** 2 + 11 ** 2)],
+                [math.sqrt(10**2 + 10**2), math.sqrt(11**2 + 11**2)],
             ),
             (
                 [Point(0, 0), Point(1, 1)],
@@ -788,7 +788,7 @@ class TestNearest:
                 [Point(1.1, 1.1), Point(0, 0)],
                 [0, 1, 2],
                 [1, 0, 1],
-                [0, np.sqrt(0.1 ** 2 + 0.1 ** 2), 0],
+                [0, np.sqrt(0.1**2 + 0.1**2), 0],
             ),
         ],
     )
@@ -852,21 +852,21 @@ class TestNearest:
                 [Point(-10, -10), Point(100, 100)],
                 [0, 1],
                 [0, 1],
-                [math.sqrt(10 ** 2 + 10 ** 2), math.sqrt(99 ** 2 + 99 ** 2)],
+                [math.sqrt(10**2 + 10**2), math.sqrt(99**2 + 99**2)],
             ),
             (
                 [Point(0, 0), Point(1, 1)],
                 [Point(x, y) for x, y in zip(np.arange(10), np.arange(10))],
                 [0, 1] + [1] * 8,
                 list(range(10)),
-                [0, 0] + [np.sqrt(x ** 2 + x ** 2) for x in np.arange(1, 9)],
+                [0, 0] + [np.sqrt(x**2 + x**2) for x in np.arange(1, 9)],
             ),
             (
                 [Point(0, 0), Point(1, 1), Point(0, 0)],
                 [Point(1.1, 1.1), Point(0, 0)],
                 [1, 0, 2],
                 [0, 1, 1],
-                [np.sqrt(0.1 ** 2 + 0.1 ** 2), 0, 0],
+                [np.sqrt(0.1**2 + 0.1**2), 0, 0],
             ),
         ],
     )
